@@ -1,7 +1,7 @@
 package Parse::Netstat;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2017-02-10'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,7 +44,7 @@ _
         },
         flavor => {
             summary => 'Flavor of netstat',
-            schema  => ['str*', in => ['linux', 'solaris', 'freebsd', 'win32']],
+            schema  => ['str*', in => ['linux', 'solaris', 'freebsd', 'darwin', 'win32']],
             default => 'linux',
         },
         tcp => {
@@ -87,6 +87,10 @@ sub parse_netstat {
         require Parse::Netstat::freebsd;
         Parse::Netstat::freebsd::parse_netstat(
             output=>$output, tcp=>$tcp, udp=>$udp, unix=>$unix);
+    } elsif ($flavor eq 'darwin') {
+        require Parse::Netstat::darwin;
+        Parse::Netstat::darwin::parse_netstat(
+            output=>$output, tcp=>$tcp, udp=>$udp, unix=>$unix);
     } elsif ($flavor eq 'solaris') {
         require Parse::Netstat::solaris;
         Parse::Netstat::solaris::parse_netstat(
@@ -115,29 +119,24 @@ Parse::Netstat - Parse the output of "netstat" command
 
 =head1 VERSION
 
-This document describes version 0.12 of Parse::Netstat (from Perl distribution Parse-Netstat), released on 2015-09-03.
+This document describes version 0.14 of Parse::Netstat (from Perl distribution Parse-Netstat), released on 2017-02-10.
 
 =head1 SYNOPSIS
 
  use Parse::Netstat qw(parse_netstat);
  my $res = parse_netstat(output => join("", `netstat -anp`), flavor=>'linux');
 
-=head1 SEE ALSO
-
-Parse::Netstat::* for per-flavor notes and sample outputs.
-
-L<App::ParseNetstat> provides a CLI for this module.
-
 =head1 FUNCTIONS
 
 
-=head2 parse_netstat(%args) -> [status, msg, result, meta]
+=head2 parse_netstat
+
+Usage:
+
+ parse_netstat(%args) -> [status, msg, result, meta]
 
 Parse the output of "netstat" command.
 
-Examples:
-
- parse_netstat();
 This program support several flavors of netstat. The default flavor is C<linux>.
 Use C<--flavor> to select which flavor you want.
 
@@ -147,6 +146,8 @@ a single flavor are supported, please see the sample parse output for each
 flavor (in corresponding C<Parse::Netstat::*> per-flavor module) you want to use
 and adjust accordingly.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -203,13 +204,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+Parse::Netstat::* for per-flavor notes and sample outputs.
+
+L<parse-netstat> from L<App::ParseNetstat> is a CLI for this module.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
